<?php
/**
 * Yule Customizer.
 *
 * @package Theme Palace
 * @subpackage Yule
 * @since Yule 1.0.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function yule_customize_register( $wp_customize ) {
	$options = yule_get_theme_options();

	// Load custom control functions.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callback.php';

	// Load partial functions.
	require get_template_directory() . '/inc/customizer/partial.php';

	// Load validation callback functions.
	require get_template_directory() . '/inc/customizer/validation.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	// Site identity extra options.
	$wp_customize->add_setting( 'yule_theme_options[header_txt_logo_extra]', array(
		'default'           => $options['header_txt_logo_extra'],
		'sanitize_callback' => 'yule_sanitize_select',
		'transport'			=> 'refresh'
	) );

	$wp_customize->add_control( 'yule_theme_options[header_txt_logo_extra]', array(
		'priority'			=> 50,
		'type'				=> 'radio',
		'label'             => esc_html__( 'Site Identity Extra Options', 'yule' ),
		'section'           => 'title_tagline',
		'choices'				=> array( 
			'hide-all'     => esc_html__( 'Hide All', 'yule' ),
			'show-all'     => esc_html__( 'Show All', 'yule' ),
			'title-only'   => esc_html__( 'Title Only', 'yule' ),
			'tagline-only' => esc_html__( 'Tagline Only', 'yule' ),
			'logo-title'   => esc_html__( 'Logo + Title', 'yule' ),
			'logo-tagline' => esc_html__( 'Logo + Tagline', 'yule' ),
			)
	) );

	// Add panel for common theme options
	$wp_customize->add_panel( 'yule_theme_options_panel' , array(
	    'title'      => esc_html__( 'Theme Options','yule' ),
	    'description'=> esc_html__( 'Yule Theme Options.', 'yule' ),
	    'priority'   => 150,
	) );

	// loader
	require get_template_directory() . '/inc/customizer/theme-options/loader.php';

	// load layout
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// load static homepage option
	require get_template_directory() . '/inc/customizer/theme-options/homepage-static.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/excerpt.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/archive.php';
	
	// load pagination option
	require get_template_directory() . '/inc/customizer/theme-options/pagination.php';

	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';

	// load reset option
	require get_template_directory() . '/inc/customizer/theme-options/reset.php';

	// Add panel for front page theme options.
	$wp_customize->add_panel( 'yule_front_page_panel' , array(
	    'title'      => esc_html__( 'Front Page','yule' ),
	    'description'=> esc_html__( 'Front Page Theme Options.', 'yule' ),
	    'priority'   => 140,
	) );

	// Load popular section option
	require get_template_directory() . '/inc/customizer/sections/popular.php';

	// Load latest section option
	require get_template_directory() . '/inc/customizer/sections/latest.php';

	// Load call to action section option
	require get_template_directory() . '/inc/customizer/sections/cta.php';
}
add_action( 'customize_register', 'yule_customize_register' );

/*
 * Load customizer sanitization functions.
 */
require get_template_directory() . '/inc/customizer/sanitize.php';

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function yule_customize_preview_js() {
	wp_enqueue_script( 'yule-customizer', get_template_directory_uri() . '/assets/js/customizer' . yule_min() . '.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'yule_customize_preview_js' );

/**
 * Load dynamic logic for the customizer controls area.
 */
function yule_customize_control_js() {
	wp_enqueue_script( 'yule-customize-controls', get_template_directory_uri() . '/assets/js/customize-controls' . yule_min() . '.js', array(), '1.0', true );
	$yule_reset_data = array(
		'reset_message' => esc_html__( 'Refresh the customizer page after saving to view reset effects', 'yule' )
	);
	// Send list of color variables as object to custom customizer js
	wp_localize_script( 'yule-customize-controls', 'yule_reset_data', $yule_reset_data );

	wp_enqueue_style( 'customize-controls-css', get_template_directory_uri() . '/assets/css/customize-controls.css' );
}
add_action( 'customize_controls_enqueue_scripts', 'yule_customize_control_js' );

if ( !function_exists( 'yule_reset_options' ) ) :
	/**
	 * Reset all options
	 *
	 * @since Yule 1.0.0
	 *
	 * @param bool $checked Whether the reset is checked.
	 * @return bool Whether the reset is checked.
	 */
	function yule_reset_options() {
		$options = yule_get_theme_options();
		if ( true === $options['reset_options'] ) {
			// Reset custom theme options.
			set_theme_mod( 'yule_theme_options', array() );
	    }
	  	else {
		    return false;
	  	}
	}
endif;
add_action( 'customize_save_after', 'yule_reset_options' );
