<?php
/**
 * Call to Action options
 *
 * @package Theme Palace
 * @subpackage Yule
 * @since Yule 1.0.0
 */

// Add cta section
$wp_customize->add_section( 'yule_cta_section', array(
	'title'             => esc_html__( 'Call to Action','yule' ),
	'description'       => esc_html__( 'Call to Action options.', 'yule' ),
	'panel'             => 'yule_front_page_panel',
) );

// cta enable control and setting
$wp_customize->add_setting( 'yule_theme_options[cta_section_enable]', array(
	'sanitize_callback' => 'yule_sanitize_switch_control',
	'default'          	=> $options['cta_section_enable'],
) );

$wp_customize->add_control( new Yule_Switch_Control( $wp_customize, 'yule_theme_options[cta_section_enable]', array(
	'label'             => esc_html__( 'Call to Action Enable', 'yule' ),
	'section'           => 'yule_cta_section',
	'on_off_label' 		=> yule_switch_options(),
) ) );

// Show page drop-down setting and control
$wp_customize->add_setting( 'yule_theme_options[cta_content_page]', array(
	'sanitize_callback' => 'yule_sanitize_page',
) );

$wp_customize->add_control( 'yule_theme_options[cta_content_page]', array(
	'label'           	=> esc_html__( 'Select Page', 'yule' ),
	'section'        	=> 'yule_cta_section',
	'active_callback' 	=> 'yule_is_cta_section_enable',
	'type'				=> 'dropdown-pages'
) );

// cta btn label setting and control
$wp_customize->add_setting( 'yule_theme_options[cta_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['cta_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'yule_theme_options[cta_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'yule' ),
	'section'        	=> 'yule_cta_section',
	'active_callback' 	=> 'yule_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'yule_theme_options[cta_btn_label]', array(
		'selector'            => '#call-to-action .more-link a.btn-default',
		'settings'            => 'yule_theme_options[cta_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'yule_cta_btn_label_partial',
    ) );
}
